## External Programmable Watchdog Timer using MSP430 MCUs

### Example Summary

This [example code](https://dev.ti.com/tirex/explore/node?node=AOdISf10q3iNOPPW4mvHwA__IOGqZri__LATEST) implements an external watchdog timer (WDT) using a MSP430 microcontroller (MCU) to monitor periodic responses from a host MCU or processor and reset it when a response isn't received within a certain interval. The host can also be reset manually. If the external WDT's interval is restarted before the interval expires, the host is not reset.

This example code supports three different ways to reset the host or restart the interval including applying signals to the input pins, pressing switches on the LaunchPad or sending UART commands from the associated GUI or a serial terminal. However, the external WDT's interval can only be changed using UART commands.The default interval is 5 seconds, but you can change it from 1 to 5 seconds in increments of 1 second.

The GUI example is available at [External Programmable Watchdog Timer](https://dev.ti.com/gallery/info/TIMSPGC/External_Programmable_Watchdog_Timer). The GUI example project is also included as a ZIP file and can be imported into [GUI Composer](https://dev.ti.com/gc/).

### Peripherals and Pin Assignments 

* P1.0 --> Reset Status (LED1)
* P1.1 --> Host Reset (LED2)
* P1.4/UCA0TXD --> Host RX
* P1.5/UCA0RXD <-- Host TX
* P2.3 <-- Manual Reset (S1)
* P2.7 <-- Watchdog Interrupt (S2)
* P2.0 --> XOUT (optional for XT1)
* P2.1 <-- XIN (optional for XT1)

All other pins are initialized as output low to reduce power consumption.

### Clock Configuration

* ACLK = REFO ~32768Hz (default)
* SMCLK = DCO + FLL + 32-KHz REFO reference = 16-MHz
* MCLK = DCO + FLL + 32-KHz REFO reference = 16-MHz

XT1 can be used as an alternative to REFO if the crystal selector resistors are changed, and XT1 is enabled in the code.

### BoosterPacks, Board Resources and Jumper Settings

This example was developed and tested on the MSP-EXP430FR2433 LaunchPad.

* Jumper J10: ON, Enables LED1 driven by P1.0
* Jumper J11: ON, Enables LED2 driven by P1.1
* Jumper J101-GND: ON, Connects GND between the on-board debugger and LaunchPad 
* Jumper J101-3V3: ON, Powers the LaunchPad through USB
* Jumper J101-RXD: ON, Enables back-channel UART communication
* Jumper J101-TXD: ON, Enables back-channel UART communication

### Example Usage

* Connect the LaunchPad to your PC using the USB cable.
* If using a host MCU or processor, connect its Watchdog Interrupt (WDI) output to J1.8 (P2.7) and its Host Reset (HRST) input to J2.19 (P1.1) on the LaunchPad.
* Identify the COM port for the MSP Application UART interface (found under "Ports" in Device Manager for Windows).
* If using the non-GUI (standalone) project:
	* Open a serial terminal (Docklight, Tera Term, etc.) with the following settings:
		```
		    COM Port:       COM# for MSP Application UART
		    Baud Rate:      9600
		    Data Bits:      8
		    Stop Bits:      1
		    Parity:         None
		    Flow Control:   None
		```
* If using the GUI project:
	* Import the GUI into [GUI Composer](https://dev.ti.com/gc/) and execute it.
	* Under "Options" > "Serial Port", update the GUI Serial Port settings:
		```
		    Ports:          COM# for MSP Application UART
		    Baud Rates:     9600
		```
	* Make sure the status at the bottom-left of the GUI shows "Hardware Connected".
	* Reset the device to initialize everything by pressing and releasing switch S3 on the LaunchPad.

* Then, continue with the example: 
	* How to manually reset the host MCU or processor
		* On the LaunchPad, push the S1 button.
		* If using the non-GUI project, send 07h over UART.
		* If using the GUI project, click on the large red "RESET" button in the GUI. This turns off the Reset Status LED and restarts the interval countdown in the GUI.
		* LED1 will turn off and then turn back on when the timeout interval expires.
		* The host reset pulse is output on P1.1 which is connected to LED2. However, the default pulse is only 1 millisecond, so it's nearly impossible to see.		* 
	* How to feed the external watchdog timer
		* "Feed" is a common term that means the reset timeout interval is restarted, preventing the watchdog timer from resetting the host.
		* On the LaunchPad, push the S2 button.
		* If using the non-GUI project, send 06h over UART.
		* If using the GUI project, click on the large "FEED" button in the GUI. This turns off the Reset Status LED and restarts the interval countdown in the GUI.
		* Keep feeding the watchdog timer before the reset interval countdown expires to prevent the watchdog timer from resetting the host.
		* If the timeout interval does expire, the host is reset every 1 second until the watchdog timer is fed or the host is manually reset.
	* How to change the timeout interval
		* This can't be changed using the buttons on the LaunchPad.
		* If using the non-GUI project, send 01h, 02h, 03h, 04h or 05h over UART.
		* If using the GUI project, make a selection using the drop-down menu in the GUI.
		* This new timeout interval will be used. If it's shorter, the watchdog timer will need to be fed more often to prevent it from resetting.